OiRA

Help

1. Presentazione
2. Processo di VR
3. Identificazione + Valutazione
4. Misure di miglioramento
5. Report
6. Stato 0%

# La valutazione del rischio nella tua organizzazione

Ai fini di effettuare la valutazione dei rischi nella tua azienda, ti verrà richiesto di:

- Selezionare l’opzione pertinente alla tua attività lavorativa
- In caso di più attività/siti/unità produttive, elencarli singolarmente utilizzando l’apposito “comando”

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More